@@ -17,7 +17,7 @@ pub mod tracing;
 macro_rules! event {
 	($x:expr) => {
 		use crate::tracing::Event::*;
-		$x.emit();
+		crate::tracing::with(|listener| listener.event($x));
 	};
 }
 
